Finch.Error exception (Finch v0.22.0)

An HTTP error.

This exception struct is used to represent errors returned by Finch that are not transport or HTTP protocol errors.

Summary

Types

reason()

@type reason() :: atom() | String.t() | term()

t()

@type t() :: %Finch.Error{__exception__: true, reason: reason()}