Finch.Error exception (Finch v0.22.0)
View SourceAn HTTP error.
This exception struct is used to represent errors returned by Finch that are not transport or HTTP protocol errors.
An HTTP error.
This exception struct is used to represent errors returned by Finch that are not transport or HTTP protocol errors.